==> aisleriot-3.16.2.tgz: lib/aisleriot/guile/2.0/athena.go <==
GOOF----BE-4-2.0  A    ] . 4        h  2    ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
g  api	
 	 	
g  primitive-load-path	f  klondike	g  deal-one	g  
deal-three	g  	no-redeal	g  
max-redeal							
		 	g  tableau					 	g  
foundation	g  stock	g  waste	g  initialize-playing-area	g  set-ace-low	g  make-standard-deck	g  shuffle-deck	g  add-normal-slot	g  DECK	g  add-partially-extended-slot	 g  right	!g  add-blank-slot	"g  add-carriage-return-slot	#g  add-extended-slot	$g  down	%g  
deal-cards	&g  deal-cards-face-up	'g  give-status-message	(g  new-game	)g  _	*f  Three card deals	+g  get-options	,g  
apply-options	-g  set-lambda!C 5 h     ] 4	 >  "  G  4
i>  "  G  RRR	RRR
RR !"#$%&'        h    ] 4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  $  4	
	>  "  G  "  4>  "  G  4>   "  G  4
>  "  G  4
>  "  G  4
>  "  G  4
>  "  G  4>   "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>   "  G  		 C             g  filenamef  
athena.scm
	)
		*			+		#	-		3	.		C	0		I	0		N	0		\	2		]	3		`	3	#	f	3	/	k	3		x	4		{	4		}	4	 	4	 	6	 	7	 	7	 	7	 	7	 	8	 	8	 	8	 	8	 	9	 	9	 	9	 	9	 	:	 	:	 	:	 	:	 	;	 	<	 	<	 	<		<		=		=		=		=	!	>	$	>	(	>	-	>	6	?	9	?	=	?	B	?	K	@	N	@	R	@	W	@	`	A	c	A	g	A	l	A	u	B	x	B	|	B		B		D		E		F		G		I		K	 F	
  g  nameg  new-game C(R)*    h      |] 45  C         t    g  filenamef  
athena.scm
	N
		O			O				O			O			O	 		
  g  nameg  get-options C+R   h      |]  C        t    g  options
		  g  filenamef  
athena.scm
	Q
		R				R	 		  g  nameg  
apply-options C,R4-i((i>  "  G  4-i++i>  "  G  -i,,i6            g  filenamef  
athena.scm		
		
	 			%	
	1	
	5	
	9	
	>	 
	@	$		C	$
	E	%		H	%
	L	&
	P	'
2	)
	N
	Q
	T
	T	
	T
	U
	U	
	U
	V	
	V
 	
   C6 

==> aisleriot-3.20.2.tgz: lib/aisleriot/guile/2.0/athena.go <==
GOOF----LE-4-2.0A      ] . 4        h2      ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
g  api	
 	 	
g  primitive-load-path	f  klondike	g  deal-one	g  
deal-three	g  	no-redeal	g  
max-redeal							
		 	g  tableau					 	g  
foundation	g  stock	g  waste	g  initialize-playing-area	g  set-ace-low	g  make-standard-deck	g  shuffle-deck	g  add-normal-slot	g  DECK	g  add-partially-extended-slot	 g  right	!g  add-blank-slot	"g  add-carriage-return-slot	#g  add-extended-slot	$g  down	%g  
deal-cards	&g  deal-cards-face-up	'g  give-status-message	(g  new-game	)g  _	*f  Three card deals	+g  get-options	,g  
apply-options	-g  set-lambda!C 5 h     ] 4	 >  "  G  4
i>  "  G  RRR	RRR
RR !"#$%&'        h    ] 4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  $  4	
	>  "  G  "  4>  "  G  4>   "  G  4
>  "  G  4
>  "  G  4
>  "  G  4
>  "  G  4>   "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>   "  G  		 C             g  filenamef  
athena.scm
	)
		*			+		#	-		3	.		C	0		I	0		N	0		\	2		]	3		`	3	#	f	3	/	k	3		x	4		{	4		}	4	 	4	 	6	 	7	 	7	 	7	 	7	 	8	 	8	 	8	 	8	 	9	 	9	 	9	 	9	 	:	 	:	 	:	 	:	 	;	 	<	 	<	 	<		<		=		=		=		=	!	>	$	>	(	>	-	>	6	?	9	?	=	?	B	?	K	@	N	@	R	@	W	@	`	A	c	A	g	A	l	A	u	B	x	B	|	B		B		D		E		F		G		I		K	 F	
  g  nameg  new-game C(R)*    h   |   ] 45  C      t       g  filenamef  
athena.scm
	N
		O			O				O			O			O	 		
  g  nameg  get-options C+R   h   |   ]  C     t       g  options
		  g  filenamef  
athena.scm
	Q
		R				R	 		  g  nameg  
apply-options C,R4-i((i>  "  G  4-i++i>  "  G  -i,,i6            g  filenamef  
athena.scm		
		
	 			%	
	1	
	5	
	9	
	>	 
	@	$		C	$
	E	%		H	%
	L	&
	P	'
2	)
	N
	Q
	T
	T	
	T
	U
	U	
	U
	V	
	V
 	
   C6 
